@@ -8,9 +8,13 @@ use holo_hash::EntryHash;
 use holo_hash::HasHash;
 use holo_hash::HeaderHash;
 use holochain_p2p::actor;
-use holochain_p2p::HolochainP2pCellT;
+use holochain_p2p::HolochainP2pDnaT;
 use holochain_p2p::HolochainP2pError;
-use holochain_p2p::MockHolochainP2pCellT;
+use holochain_p2p::MockHolochainP2pDnaT;
+use holochain_sqlite::db::DbKindAuthored;
+use holochain_sqlite::db::DbKindDht;
+use holochain_sqlite::db::DbKindOp;
+use holochain_sqlite::db::DbKindT;
 use holochain_sqlite::db::WriteManager;
 use holochain_sqlite::prelude::DatabaseResult;
 use holochain_sqlite::rusqlite::Transaction;
@@ -23,8 +27,8 @@ use holochain_types::activity::AgentActivityResponse;
 use holochain_types::dht_op::DhtOpHashed;
 use holochain_types::dht_op::WireOps;
 use holochain_types::element::WireElementOps;
-use holochain_types::env::EnvRead;
-use holochain_types::env::EnvWrite;
+use holochain_types::env::DbRead;
+use holochain_types::env::DbWrite;
 use holochain_types::link::WireLinkKey;
 use holochain_types::link::WireLinkOps;
 use holochain_types::metadata::MetadataSet;
@@ -48,19 +52,19 @@ mod entry_test_data;
 
 #[derive(Clone)]
 pub struct PassThroughNetwork {
-    envs: Vec<EnvRead>,
+    envs: Vec<DbRead<DbKindDht>>,
     authority: bool,
 }
 
 impl PassThroughNetwork {
-    pub fn authority_for_all(envs: Vec<EnvRead>) -> Self {
+    pub fn authority_for_all(envs: Vec<DbRead<DbKindDht>>) -> Self {
         Self {
             envs,
             authority: true,
         }
     }
 
-    pub fn authority_for_nothing(envs: Vec<EnvRead>) -> Self {
+    pub fn authority_for_nothing(envs: Vec<DbRead<DbKindDht>>) -> Self {
         Self {
             envs,
             authority: false,
@@ -69,16 +73,16 @@ impl PassThroughNetwork {
 }
 
 #[derive(Clone)]
-pub struct MockNetwork(std::sync::Arc<tokio::sync::Mutex<MockHolochainP2pCellT>>);
+pub struct MockNetwork(std::sync::Arc<tokio::sync::Mutex<MockHolochainP2pDnaT>>);
 
 impl MockNetwork {
-    pub fn new(mock: MockHolochainP2pCellT) -> Self {
+    pub fn new(mock: MockHolochainP2pDnaT) -> Self {
         Self(std::sync::Arc::new(tokio::sync::Mutex::new(mock)))
     }
 }
 
 #[async_trait::async_trait]
-impl HolochainP2pCellT for PassThroughNetwork {
+impl HolochainP2pDnaT for PassThroughNetwork {
     async fn get_validation_package(
         &self,
         _request_from: AgentPubKey,
@@ -174,31 +178,9 @@ impl HolochainP2pCellT for PassThroughNetwork {
         todo!()
     }
 
-    fn from_agent(&self) -> AgentPubKey {
-        todo!()
-    }
-
-    async fn join(&self) -> actor::HolochainP2pResult<()> {
-        todo!()
-    }
-
-    async fn leave(&self) -> actor::HolochainP2pResult<()> {
-        todo!()
-    }
-
-    async fn call_remote(
-        &self,
-        _to_agent: AgentPubKey,
-        _zome_name: holochain_zome_types::ZomeName,
-        _fn_name: holochain_zome_types::FunctionName,
-        _cap_secret: Option<holochain_zome_types::CapSecret>,
-        _payload: holochain_zome_types::ExternIO,
-    ) -> actor::HolochainP2pResult<holochain_serialized_bytes::SerializedBytes> {
-        todo!()
-    }
-
     async fn remote_signal(
         &self,
+        _from_agent: AgentPubKey,
         _to_agent_list: Vec<AgentPubKey>,
         _zome_name: holochain_zome_types::ZomeName,
         _fn_name: holochain_zome_types::FunctionName,
@@ -238,14 +220,34 @@ impl HolochainP2pCellT for PassThroughNetwork {
     async fn new_integrated_data(&self) -> actor::HolochainP2pResult<()> {
         todo!()
     }
+
+    async fn join(&self, _agent: AgentPubKey) -> actor::HolochainP2pResult<()> {
+        todo!()
+    }
+
+    async fn leave(&self, _agent: AgentPubKey) -> actor::HolochainP2pResult<()> {
+        todo!()
+    }
+
+    async fn call_remote(
+        &self,
+        _from_agent: AgentPubKey,
+        _to_agent: AgentPubKey,
+        _zome_name: holochain_zome_types::ZomeName,
+        _fn_name: holochain_zome_types::FunctionName,
+        _cap: Option<holochain_zome_types::CapSecret>,
+        _payload: holochain_zome_types::ExternIO,
+    ) -> actor::HolochainP2pResult<holochain_serialized_bytes::SerializedBytes> {
+        todo!()
+    }
 }
 
-pub fn fill_db(env: &EnvWrite, op: DhtOpHashed) {
+pub fn fill_db<Db: DbKindT + DbKindOp>(env: &DbWrite<Db>, op: DhtOpHashed) {
     env.conn()
         .unwrap()
         .with_commit_sync(|txn| {
             let hash = op.as_hash().clone();
-            insert_op(txn, op, false).unwrap();
+            insert_op(txn, op).unwrap();
             set_validation_status(txn, hash.clone(), ValidationStatus::Valid).unwrap();
             set_when_integrated(txn, hash, Timestamp::now()).unwrap();
             DatabaseResult::Ok(())
@@ -253,12 +255,12 @@ pub fn fill_db(env: &EnvWrite, op: DhtOpHashed) {
         .unwrap();
 }
 
-pub fn fill_db_rejected(env: &EnvWrite, op: DhtOpHashed) {
+pub fn fill_db_rejected<Db: DbKindT + DbKindOp>(env: &DbWrite<Db>, op: DhtOpHashed) {
     env.conn()
         .unwrap()
         .with_commit_sync(|txn| {
             let hash = op.as_hash().clone();
-            insert_op(txn, op, false).unwrap();
+            insert_op(txn, op).unwrap();
             set_validation_status(txn, hash.clone(), ValidationStatus::Rejected).unwrap();
             set_when_integrated(txn, hash, Timestamp::now()).unwrap();
             DatabaseResult::Ok(())
@@ -266,30 +268,30 @@ pub fn fill_db_rejected(env: &EnvWrite, op: DhtOpHashed) {
         .unwrap();
 }
 
-pub fn fill_db_pending(env: &EnvWrite, op: DhtOpHashed) {
+pub fn fill_db_pending<Db: DbKindT + DbKindOp>(env: &DbWrite<Db>, op: DhtOpHashed) {
     env.conn()
         .unwrap()
         .with_commit_sync(|txn| {
             let hash = op.as_hash().clone();
-            insert_op(txn, op, false).unwrap();
+            insert_op(txn, op).unwrap();
             set_validation_status(txn, hash, ValidationStatus::Valid).unwrap();
             DatabaseResult::Ok(())
         })
         .unwrap();
 }
 
-pub fn fill_db_as_author(env: &EnvWrite, op: DhtOpHashed) {
+pub fn fill_db_as_author(env: &DbWrite<DbKindAuthored>, op: DhtOpHashed) {
     env.conn()
         .unwrap()
         .with_commit_sync(|txn| {
-            insert_op(txn, op, true).unwrap();
+            insert_op(txn, op).unwrap();
             DatabaseResult::Ok(())
         })
         .unwrap();
 }
 
 #[async_trait::async_trait]
-impl HolochainP2pCellT for MockNetwork {
+impl HolochainP2pDnaT for MockNetwork {
     async fn get_validation_package(
         &self,
         request_from: AgentPubKey,
@@ -350,31 +352,9 @@ impl HolochainP2pCellT for MockNetwork {
         todo!()
     }
 
-    fn from_agent(&self) -> AgentPubKey {
-        todo!()
-    }
-
-    async fn join(&self) -> actor::HolochainP2pResult<()> {
-        todo!()
-    }
-
-    async fn leave(&self) -> actor::HolochainP2pResult<()> {
-        todo!()
-    }
-
-    async fn call_remote(
-        &self,
-        _to_agent: AgentPubKey,
-        _zome_name: holochain_zome_types::ZomeName,
-        _fn_name: holochain_zome_types::FunctionName,
-        _cap_secret: Option<holochain_zome_types::CapSecret>,
-        _payload: holochain_zome_types::ExternIO,
-    ) -> actor::HolochainP2pResult<holochain_serialized_bytes::SerializedBytes> {
-        todo!()
-    }
-
     async fn remote_signal(
         &self,
+        _from_agent: AgentPubKey,
         _to_agent_list: Vec<AgentPubKey>,
         _zome_name: holochain_zome_types::ZomeName,
         _fn_name: holochain_zome_types::FunctionName,
@@ -414,6 +394,26 @@ impl HolochainP2pCellT for MockNetwork {
     async fn new_integrated_data(&self) -> actor::HolochainP2pResult<()> {
         todo!()
     }
+
+    async fn join(&self, _agent: AgentPubKey) -> actor::HolochainP2pResult<()> {
+        todo!()
+    }
+
+    async fn leave(&self, _agent: AgentPubKey) -> actor::HolochainP2pResult<()> {
+        todo!()
+    }
+
+    async fn call_remote(
+        &self,
+        _from_agent: AgentPubKey,
+        _to_agent: AgentPubKey,
+        _zome_name: holochain_zome_types::ZomeName,
+        _fn_name: holochain_zome_types::FunctionName,
+        _cap: Option<holochain_zome_types::CapSecret>,
+        _payload: holochain_zome_types::ExternIO,
+    ) -> actor::HolochainP2pResult<holochain_serialized_bytes::SerializedBytes> {
+        todo!()
+    }
 }
 
 pub fn wire_to_shh<T: TryInto<SignedHeader> + Clone>(op: &T) -> SignedHeaderHashed {
